==> benno-web-2.1.0.tgz: srv/benno/bennoweb/htdocs/ctrl/a_deleteQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

require_once 'model/StoredQuery.php';
$queryId = $App->getParam('queryId');

$User = $App->getSession('USER');

$StoredQuery = new StoredQuery($queryId);
$StoredQuery->delete();

try {
    $QueryList = StoredQuery::FetchList($User->id);
    $App->setSession('QueryList',$QueryList);
}
catch (Exception $e) {
    $App->log('[storeQuery] '.$e->getMessage());
    $App->setMsg($e->getMessage());
}

# response without html header and footer
$App->assign('EMPTY',true);
$App->view = 'a_queryList';

?>

==> benno-web-2.10.8.tgz: srv/benno/bennoweb/htdocs/ctrl/a_deleteQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

require_once 'model/StoredQuery.php';
$queryId = $App->getParam('queryId');

$USER = $App->getSession('USER');

$StoredQuery = new StoredQuery($queryId);
$StoredQuery->delete();

try {
    $QueryList = StoredQuery::FetchList($USER->id);
    $App->setSession('QueryList',$QueryList);
}
catch (Exception $e) {
    $App->log('[storeQuery] '.$e->getMessage());
    $App->setMsg($e->getMessage());
}

# response without html header and footer
$App->assign('EMPTY',true);
$App->view = 'a_queryList';

?>
